state property
RestartBaseState
get
state
Gets the current restart state.
This state contains the current session key used by the widget tree.
Implementation
RestartBaseState get state => _state;
Gets the current restart state.
This state contains the current session key used by the widget tree.
RestartBaseState get state => _state;