RestartState class

Concrete implementation of restart state.

This class represents a specific restart state with an associated session key. It extends RestartBaseState to provide the actual state implementation used by the RestartNotifier.

Inheritance

Constructors

RestartState(Key appSessionKey)
Creates a new restart state with the given session key.
const

Properties

appSessionKey → Key
The session key associated with this restart state.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited